@@ -21,12 +21,15 @@
 #include <kdebug.h>
 #include <QRegExp>
 #include <QStringList>
+#include "kolabformat/errorhandler.h"
 
 QString TimezoneConverter::normalizeTimezone(const QString& tz)
 {
     KTimeZone timezone = KSystemTimeZones::zone(tz); //Needs ktimezoned (timezone daemon running) http://api.kde.org/4.x-api/kdelibs-apidocs/kdecore/html/classKSystemTimeZones.html
     if (timezone.isValid()) {
         return tz;
+    } else if (!KSystemTimeZones::isTimeZoneDaemonAvailable()) {
+        Error() << "ktimezoned is not available and required for timezone interpretation";
     }
     //We're dealing with an invalid or unknown timezone, try to parse it
     QString guessedTimezone = fromCityName(tz);
@@ -36,6 +39,7 @@ QString TimezoneConverter::normalizeTimezone(const QString& tz)
     if (guessedTimezone.isEmpty()) {
         guessedTimezone = fromGMTOffsetTimezone(tz);
     }
+    Debug() << "Guessed timezone and found: " << guessedTimezone;
     return guessedTimezone;
 }
 
